@@ -54,7 +54,6 @@ def run_userinit(fname):
 
 URL_CHECKVERSION = 'http://www.gembook.org/kaa_checkversion/version_latest'
 CHECK_DURARION = 60*60*24 # check once a day.
-CHECK_DURARION = 1
 
 def _download_version_no():
     import urllib.request
@@ -67,7 +66,7 @@ def _download_version_no():
 
     m = re.match(r'(\d+)\.(\d+)\.(\d+)', s)
     if m:
-        latest = tuple(int(v) for v in m.groups()[1:])
+        latest = tuple(int(v) for v in m.groups())
         if latest > version.KAA_VERSION:
             kaa.app.messagebar.set_message('')
             kaa.app.call_later(1, kaa.app.messagebar.set_message, 
